<?php

/**
 * @file
 * Admin settings for Presentation module.
 */

/**
 * Admin callback
 * Most of these settings will be moved to a Content Type-based Presentation Profile system.
 */
function presentation_admin_settings() {
  $plugins = presentation_get_plugins();

  // Build an array of options for plugin selection.
  $default_plugin_options = $plugins;
  presentation_plugins_enabled($default_plugin_options);
  $default_plugin_options = presentation_plugins_options($default_plugin_options);

  $form = array();
  $form['presentation_default_plugin'] = array(
    '#type' => 'select',
    '#title' => t('Default Plugin'),
    '#default_value' => presentation_variable_get('default_plugin'),
    '#options' => $default_plugin_options,
  );

  $form['presentation_node'] = array(
    '#type' => 'fieldset',
    '#title' => t('Node Presentation Settings'),
    '#description' => t('Configure node presentations.'),
    '#collapsible' => TRUE,
  );

  // Set content types usable as presentations
  $types = node_get_types('names');
  $form['presentation_node']['presentation_allowed_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Allowed presentation types'),
    '#default_value' => presentation_variable_get('allowed_node_types'),
    '#options' => $types,
    '#description' => t('Select content types to be exportable as presentations'),
    '#required' => TRUE,
  );

  $form['presentation_node']['presentation_node_link_text'] = array(
    '#type' => 'textfield',
    '#title' => t('Presentation Link Text'),
    '#default_value' => presentation_variable_get('node_link_text'),
  );
  
  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
    '#title' => t('Advanced Settings'),
  );

  // Source content for presentation.
  $source = presentation_variable_get('slide_source');
  $form['advanced']['presentation_slide_source'] = array(
    '#type' => 'fieldset',
    '#description' => t('Define the source content for your presentation.'),
    '#tree' => TRUE,
    '#title' => t('Slide Source Content'),
    '#collapsible' => TRUE,
  );

  $form['advanced']['presentation_slide_source']['type'] = array(
    '#type' => 'select',
    '#default_value' => $source['type'],
    '#options' => array('node' => 'node'),
    '#description' => t('Define the type of content source to use.'),
  );

  $form['advanced']['presentation_slide_source']['content'] = array(
    '#type' => 'textarea',
    '#title' => t('Source Content'),
    '#default_value' => $source['content'],
    '#description' => t('Use tokens to define slide content. Each row will be on a separate slide, and may be broken down further depending on the plugin. NOTE - Node body is used first. Then additional content as defined here.'),
  );

  // Build-in forms for presentation arguments.
  $form['advanced']['presentation_default_arguments'] = array(
    '#title' => t('Presentation Defaults'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#tree' => TRUE,
  );

  $form['advanced']['presentation_default_arguments']['title'] = array(
    '#type' => 'textfield',
    '#title' => t('Presentation Title'),
    '#default_value' => presentation_variable_get('default_arguments', 'title'),
  );

  $form['advanced']['presentation_default_arguments']['author'] = array(
    '#type' => 'textfield',
    '#title' => t('Presentation Author'),
    '#default_value' => presentation_variable_get('default_arguments', 'author'),
  );

  $form['advanced']['presentation_default_arguments']['email'] = array(
    '#type' => 'textfield',
    '#title' => t('Presentation Email'),
    '#default_value' => presentation_variable_get('default_arguments', 'email'),
  );

  $form['advanced']['presentation_default_arguments']['date'] = array(
    '#type' => 'textfield',
    '#title' => t('Presentation Date'),
    '#default_value' => presentation_variable_get('default_arguments', 'date'),
  );

  $form['advanced']['presentation_default_arguments']['organization'] = array(
    '#type' => 'textfield',
    '#title' => t('Organization'),
    '#default_value' => presentation_variable_get('default_arguments', 'organization'),
  );

  $form['advanced']['presentation_default_arguments']['location'] = array(
    '#type' => 'textfield',
    '#title' => t('Location'),
    '#default_value' => presentation_variable_get('default_arguments', 'location'),
  );

  $form['advanced']['token_help'] = array(
    '#title' => t('Replacement patterns'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['advanced']['token_help']['help'] = array(
    '#value' => theme('token_help', 'node'),
  );
  
  $libraries = array();
  $collapsed = FALSE;
  foreach ($plugins as $plugin) {
    // Append plugin-specific configuration.
    if ($plugin['enabled'] && function_exists($plugin['settings'])) {
      $index = 'presentation_' . $plugin['machine_name'] . '_settings';
      $form[$index] = array(
        '#type' => 'fieldset',
        '#title' => t('!plugin settings', array('!plugin' => $plugin['label'])),
        '#collapsible' => TRUE,
        '#tree' => TRUE,
      );
      $result = call_user_func_array($plugin['settings'], array($plugin));
      foreach ($result as $eid => $element) {
        $form[$index][$eid] = $element;
      }
    }
    if ($plugin['library'] == PRESENTATION_SIMPLE_PLUGIN) {
      continue;
    }
    $version = !empty($plugin['package']['version']) ? ' [Version ' . $plugin['package']['version'] . ']' : '';
  
    $library_header = l($plugin['label'] . $version, $plugin['package']['homepage'])
      . ' (' . l(t('Download'), $plugin['package']['download']) . ')';

    if (!is_dir($plugin['library'])) {
      $libraries[] = array($library_header);
      $libraries[] = array($plugin['package']['help']);
    }
    else {
      $libraries[] = array($library_header . t(' – Found at %path.', array('%path' => $plugin['library'])));
      $libraries[] = array();
      $collapsed = TRUE;
    }
  }
  // Collect info on missing libraries.
  $form['libraries'] = array(
    '#type' => 'fieldset',
    '#title' => t('Presentation package'),
    '#collapsible' => TRUE,
    '#collapsed' => $collapsed,
  );

  $form['libraries']['table'] = array(
    '#value' => theme('table', array(), $libraries),
  );

  return system_settings_form($form);
}
