<?php

/**
 * @file
 *  Provide core display plugins for presentation module.
 */ 

/**
 * Return default "handout" plugin.
 * The handout plugin is very basic and relies on default processing for all behaviors.
 * You may override theme/presentation-handout-export.tpl.php to change it's appearance.
 */
function presentation_presentation_plugin_info() {
  $plugins = array();
  $plugins['handout'] = array(
    'process' => 'presentation_text_raw_process',
    'library' => PRESENTATION_SIMPLE_PLUGIN,
  );
  $plugins['s5'] = array(
    'label' => t('s5 Presentation'),
    'process' => 'presentation_text_slides_by_heading_process',
    'settings' => 'presentation_s5_settings',
    'options' => variable_get('presentation_s5_settings', array('theme' => 'default')),
    'package' => array(
      'version' => '1.1',
      'homepage' => 'http://meyerweb.com/eric/tools/s5/',
      'help' => t('Unzip the s5 package and move the contents to directory to presentation/libraries/s5/.'),
    ),
  );
  $plugins['slippy'] = array(
    'label' => t('Slippy Presentation'),
    'process' => 'presentation_text_slides_by_heading_process',
    'settings' => 'presentation_slippy_settings',
    'options' => variable_get('presentation_slippy_settings', array('theme' => 'dark')),
    'package' => array(
      'version' => '1.0',
      'homepage' => 'http://seld.be/notes/introducing-slippy-html-presentations',
      'download' => 'http://github.com/Seldaek/slippy',
      'help' => t('Decompress the Slippy package and move the contents to presentation/libraries/slippy/.'),
    ),
  );
  
  return $plugins;
}

/**
 * Settings callback for s5 plugin.
 */
function presentation_s5_settings($plugin) {
  $form = array();
  $themes = array();
  $plugin['library'] .= '/ui';
  foreach (scandir($plugin['library']) as $handle) {
    if (is_dir($plugin['library'] . '/' . $handle) && $handle != '.' && $handle != '..') {
      $theme = basename($handle);
      $themes[$theme] = $theme;
    }
  }
  $form['theme'] = array(
    '#type' => 'select',
    '#title' => t('S5 Theme'),
    '#default_value' => $plugin['options']['theme'],
    '#options' => $themes,
    '#description' => t('Select a theme.')
  );
  return $form;
}

/**
 * Settings callback for s5 plugin.
 */
function presentation_slippy_settings($plugin) {
  $form = array();
  $themes = array(
    'dark' => t('Dark'),
    'pure' => t('Pure'),
  );

  $form['theme'] = array(
    '#type' => 'select',
    '#title' => t('Slippy Theme'),
    '#default_value' => $plugin['options']['theme'],
    '#options' => $themes,
    '#description' => t('Select a theme.')
  );
  return $form;
}

function presentation_preprocess_presentation_export_s5(&$vars) {
  if (empty($vars['inline_styles'])) {
    $vars['inline_styles'] = '';
  }
  $vars['inline_styles'] .= 'h2>:link, h2>:visited {color: #99a; font-size:80%;}';
}

/**
 * Preprocesser for slippy presentations.
 */
function presentation_preprocess_presentation_export_slippy(&$vars) {
  $path = $vars['plugin']['library'];
  $query_string = '?' . substr(variable_get('css_js_query_string', '0'), 0, 1);

  drupal_set_html_head('<!-- Slippy JS -->');
  $scripts = array(
    '/src/jquery-1.4.2.min',
    '/src/jquery.history',
    '/src/slippy-0.9.0',
  );
  foreach ($scripts as $js) {
    drupal_set_html_head('<script type="text/javascript" src="' . $path . $js . '.js' . $query_string . '"></script>');
  }
  $vars['theme'] = $path . '/src/slippy-' . $vars['plugin']['options']['theme'] . '.css';
}
